// SPDX-License-Identifier: BSD-3-Clause
pragma solidity ^0.8.4;

import "@openzeppelin/contracts/token/ERC20/ERC20.sol";

contract NativeX is ERC20 {

    address private contractOwner;
    uint256 public multiplier; 

    constructor(string memory _name, string memory _symbol, uint256 _multiplier) ERC20(_name, _symbol) {
        require(_multiplier <= 1e18, "The max multiplier is 1e18.");
        contractOwner = msg.sender;
        multiplier = _multiplier;
    }

    function withdrawNative(uint256 _tokens) public {
        require(balanceOf(msg.sender) >= _tokens, "You have an insufficient number of tokens.");
        _burn(msg.sender, _tokens);
        (bool success, ) = msg.sender.call{value: (_tokens * 1 ether) / multiplier }("");
        require(success, "We cannot withdraw your native tokens at this time.");
    }

    function decimals() public view override returns (uint8) {
        return 0;
    }

    receive() external payable {
        require(msg.value % 1 ether == 0, "You must send an integer amount of native tokens.");
        uint256 newTokens = (msg.value / 1 ether) * multiplier;
        _mint(msg.sender, newTokens);
    }
    
    function burnTokens(uint256 _tokens) public {
        _burn(msg.sender, _tokens);
    }

    function transferContractOwner(address newOwner) public {
        require(msg.sender == contractOwner, "Only the contract owner can use this function.");
        contractOwner = newOwner;
    }

}
